@@ -28,9 +28,9 @@ class ChangeEvent(TicketEvent):
         created_by_user: Optional[User],
         created_at: str,
         changes: List[Change],
-        visible_to_customer: bool,
+        internal: bool,
         comment: Optional[str] = None,
     ):
-        super().__init__(created_by_user, created_at, visible_to_customer)
+        super().__init__(created_by_user, created_at, internal)
         self.changes = changes
         self.comment = comment
